@@ -2,8 +2,8 @@ package simpleXMLParse;
 
 # Perl Module: simpleXMLParse
 # Author: Daniel Edward Graham
-# Copyright (c) Daniel Edward Graham 2008-2014
-# Date: 12/21/2014 
+# Copyright (c) Daniel Edward Graham 2008-2015
+# Date: 2/17/2015 
 # License: LGPL 3.0
 # 
 
@@ -24,10 +24,11 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 	
 );
 
-$VERSION = '2.8';
+$VERSION = '2.9';
 
 use Carp;
 use strict;
+no warnings;
 
 use open ':encoding(utf8)';
 
@@ -192,7 +193,7 @@ sub _ParseXML {
     $firsttag =~ s/\^/\\\^/gs;
     $firsttag =~ s/\-/\\\-/gs;
 
-    if ( $xml =~ /^[\s\n]*\<${firsttag}(\>|[\s\n]\>|[\s\n][^\>]*[^\/]\>)(.*?)\<\/${firsttag}\>(.*)$/s )
+    if ( $xml =~ /^[\s\n]*\<${firsttag}(\>|[\s\n]\>|[\s\n][^\>]*[^\/]\>)(.*?)\<\/${firsttag}[\s\n]*\>(.*)$/s )
     {
         $attr        = $1;
         $innerxml    = $2;
@@ -215,8 +216,9 @@ sub _ParseXML {
     my $ixml = $innerxml;
     while ($ixml =~ /^.*?\<${firsttag}(\>|[\s\n]\>|[\s\n][^\>]*[^\/]\>)(.*?)$/s) {
         $ixml = $2;
+        print STDERR "***\n";
         $innerxml .= "</${firsttag}>";
-        if ($xmlfragment =~ /^(.*?)\<\/${firsttag}\>(.*)$/s) {
+        if ($xmlfragment =~ /^(.*?)\<\/${firsttag}[\s\n]*\>(.*)$/s) {
             my $ix = $1;
             $innerxml .= $ix;
             $ixml .= $ix; 
@@ -245,7 +247,7 @@ sub _ParseXML {
     $attrcnt++;
     while (1) {
         if ( $xmlfragment =~
-            /^(.*?)\<${firsttag}(\>|[\s\n]\>|[\s\n][^\>]*[^\/]\>)(.*?)\<\/${firsttag}\>(.*)$/s )
+            /^(.*?)\<${firsttag}(\>|[\s\n]\>|[\s\n][^\>]*[^\/]\>)(.*?)\<\/${firsttag}[\s\n]*\>(.*)$/s )
         {
             if ( !$retflag ) {
                 push @retarr, $nextparse;
@@ -297,7 +299,7 @@ sub _ParseXML {
         while ($ixml =~ /.*?\<${firsttag}(\>|[\s\n]\>|[\s\n][^\>]*[^\/]\>)(.*?)$/s) {
             $ixml = $2;
             $innerxml .= "</${firsttag}>";
-            if ($xmlfragment2 =~ /(.*?)\<\/${firsttag}\>(.*)$/s) {
+            if ($xmlfragment2 =~ /(.*?)\<\/${firsttag}[\s\n]*\>(.*)$/s) {
                 my $ix = $1;
                 $innerxml .= $ix;
                 $ixml .= $ix;
